@@ -46,8 +46,12 @@ describe Raven::Configuration do
       expect(subject[:async?]).to eq(false)
     end
 
-    it 'should catch_debugged_exceptions' do
-      expect(subject[:catch_debugged_exceptions]).to eq(true)
+    it 'should catch rescued exceptions' do
+      expect(subject[:rails_report_rescued_exceptions]).to eq(true)
+    end
+
+    it 'should not have a failure callback' do
+      expect(subject[:transport_failure_callback]).to eq(false)
     end
 
     it 'should have no sanitize fields' do
@@ -101,18 +105,24 @@ describe Raven::Configuration do
   context 'configuring for async' do
     it 'should be configurable to send events async' do
       subject.async = lambda { |_e| :ok }
-      expect(subject.async.respond_to?(:call)).to eq(true)
       expect(subject.async.call('event')).to eq(:ok)
     end
 
     it 'should raise when setting async to anything other than callable or false' do
-      expect { subject.async = Proc.new {} }.to_not raise_error
-      expect { subject.async = lambda {} }.to_not raise_error
-      expect { subject.async = false }.to_not raise_error
+      subject.transport_failure_callback = lambda {}
+      subject.transport_failure_callback = false
       expect { subject.async = true }.to raise_error(ArgumentError)
     end
   end
 
+  context 'configuring for server error callback' do
+    it 'should raise when setting to anything other than callable or false' do
+      subject.transport_failure_callback = lambda {}
+      subject.transport_failure_callback = false
+      expect { subject.transport_failure_callback = true }.to raise_error(ArgumentError)
+    end
+  end
+
   context 'being initialized with a current environment' do
     before(:each) do
       subject.current_environment = 'test'
